Remove FileException, DirectoryException and LinkException from dart:io and use FileSystemException instaed.

BUG=https://code.google.com/p/dart/issues/detail?id=12461
R=nweiz@google.com, sgjesse@google.com

Review URL: https://codereview.chromium.org//26968003

git-svn-id: https://dart.googlecode.com/svn/branches/bleeding_edge/dart/pkg/watcher@29168 260f80e4-7a28-3924-810f-c04153c831b5
diff --git a/pkgs/watcher/lib/src/utils.dart b/pkgs/watcher/lib/src/utils.dart
index 319835e..3d00c08 100644
--- a/pkgs/watcher/lib/src/utils.dart
+++ b/pkgs/watcher/lib/src/utils.dart
@@ -6,9 +6,10 @@
 
 import 'dart:io';
 
 /// Returns `true` if [error] is a [DirectoryException] for a missing directory.
 bool isDirectoryNotFoundException(error) {
-  if (error is! DirectoryException) return false;
+  if (error is! FileSystemException) return false;
 
   // See dartbug.com/12461 and tests/standalone/io/directory_error_test.dart.
   var notFoundCode = Platform.operatingSystem == "windows" ? 3 : 2;
@@ -6,9 +6,10 @@
 import 'dart:io';
 
-/// Returns `true` if [error] is a [DirectoryException] for a missing directory.
+/// Returns `true` if [error] is a [FileSystemException] for a missing
+/// directory.
 bool isDirectoryNotFoundException(error) {